diff scripts/deprecated/find_dir_in_path.m @ 18074:1e27079409bf

Rename function dir_in_path to dir_in_loadpath. * NEWS: Announce new function in 4.2. * scripts/deprecated/find_dir_in_path.m: Call dir_in_loadpath as replacement. * utils.cc (Fdir_in_loadpath): Renamed dir_in_path to dir_in_loadpath. * help.m, what.m, rundemos.m, runtests.m: Chane instances of dir_in_path to dir_in_loadpath. * utils.cc, variables.cc: Change seealso links to point to dir_in_loadpath. * func.txi: Document dir_in_loadpath function.
author Rik <rik@octave.org>
date Wed, 04 Dec 2013 08:23:42 -0800
parents ff05d5b70411
children ebd27d8c63fd
line wrap: on
line diff
--- a/scripts/deprecated/find_dir_in_path.m
+++ b/scripts/deprecated/find_dir_in_path.m
@@ -19,8 +19,8 @@
 ## -*- texinfo -*-
 ## @deftypefn  {Built-in Function} {} find_dir_in_path (@var{dir})
 ## @deftypefnx {Built-in Function} {} find_dir_in_path (@var{dir}, "all")
 ## This function has been deprecated.  Use @code{dir_in_path} instead.
 ## @seealso{dir_in_path}
 ## @end deftypefn
 
 ## Deprecated in version 4.2
@@ -31,10 +31,10 @@
   if (! warned)
     warned = true;
     warning ("Octave:deprecated-function",
-             "find_dir_in_path is obsolete and will be removed from a future version of Octave, please use dir_in_path instead");
+             "find_dir_in_path is obsolete and will be removed from a future version of Octave, please use dir_in_loadpath instead");
   endif
 
-  retval = dir_in_path (varargin{:});
+  retval = dir_in_loadpath (varargin{:});
 
 endfunction
@@ -19,8 +19,8 @@
 ## @deftypefn  {Built-in Function} {} find_dir_in_path (@var{dir})
 ## @deftypefnx {Built-in Function} {} find_dir_in_path (@var{dir}, "all")
-## This function has been deprecated.  Use @code{dir_in_path} instead.
-## @seealso{dir_in_path}
+## This function has been deprecated.  Use @code{dir_in_loadpath} instead.
+## @seealso{dir_in_loadpath}
 ## @end deftypefn
 